"""

print "What is your name?"
name = raw_input()
if name == "Sam":
	print "What the hell, %s? Make it yourself." % name
elif name == "Boss":
	print "Yes sir!"
else: 
	print "Thank you, %s. I'll be sure to tell your mother." % name